@@ -8,8 +8,7 @@ use File::Path;
 use IO::File;
 use FindBin;
 use Template;
-use Catalyst;
-use Catalyst::Exception;
+our $CATALYST_SCRIPT_GEN = 2;
 
 my %cache;
 
@@ -40,7 +39,7 @@ sub get_file {
         $cache{$class} = eval "package $class; <DATA>";
     }
     my $data = $cache{$class};
-    my @files = split /^__(.+)__\r?\n/m, $data;
+    my @files = split /^__(.+)__\n/m, $data;
     shift @files;
     while (@files) {
         my ( $name, $content ) = splice @files, 0, 2;
@@ -61,22 +60,18 @@ sub mk_app {
     $self->{name} = $name;
     $self->{dir}  = $name;
     $self->{dir} =~ s/\:\:/-/g;
-    $self->{appprefix} = lc $self->{dir};
-    $self->{appprefix} =~ s/-/_/g;
     $self->{startperl} = $Config{startperl};
-    $self->{scriptgen} = $Catalyst::CATALYST_SCRIPT_GEN || 4;
-    $self->{author}    = $self->{author} = $ENV{'AUTHOR'}
-      || eval { @{ [ getpwuid($<) ] }[6] }
-      || 'Catalyst developer';
+    $self->{scriptgen}=$CATALYST_SCRIPT_GEN;
+    $self->{author}=$self->{author} = $ENV{'AUTHOR'} ||
+                    @{[getpwuid($<)]}[6];
     $self->_mk_dirs;
     $self->_mk_appclass;
-    $self->_mk_build;
     $self->_mk_makefile;
     $self->_mk_readme;
     $self->_mk_changes;
     $self->_mk_apptest;
     $self->_mk_cgi;
-    $self->_mk_fastcgi;
+    $self->_mk_fcgi;
     $self->_mk_server;
     $self->_mk_test;
     $self->_mk_create;
@@ -94,28 +89,22 @@ sub mk_component {
     my $self = shift;
     my $app  = shift;
     $self->{app} = $app;
-    $self->{author} = $self->{author} = $ENV{'AUTHOR'}
-      || eval { @{ [ getpwuid($<) ] }[6] }
-      || 'A clever guy';
+    $self->{author}=$self->{author} = $ENV{'AUTHOR'} ||
+                    @{[getpwuid($<)]}[6];
     $self->{base} = File::Spec->catdir( $FindBin::Bin, '..' );
-    unless ( $_[0] =~ /^(?:model|m|view|v|controller|c)$/i ) {
+    unless ( $_[0] =~ /^model|m|view|v|controller|c\$/i ) {
         my $helper = shift;
         my @args   = @_;
         my $class  = "Catalyst::Helper::$helper";
         eval "require $class";
-
-        if ($@) {
-            Catalyst::Exception->throw(
-                message => qq/Couldn't load helper "$class", "$@"/ );
-        }
-
+        die qq/Couldn't load helper "$class", "$@"/ if $@;
         if ( $class->can('mk_stuff') ) {
             return 1 unless $class->mk_stuff( $self, @args );
         }
     }
     else {
         my $type   = shift;
-        my $name   = shift || "Missing name for model/view/controller";
+        my $name   = shift;
         my $helper = shift;
         my @args   = @_;
         return 0 if $name =~ /[^\w\:]/;
@@ -135,7 +124,7 @@ sub mk_component {
             my @path = split /\:\:/, $name;
             $file = pop @path;
             $path = File::Spec->catdir( $path, @path );
-            mkpath [$path];
+            mkpath $path;
         }
         $file = File::Spec->catfile( $path, "$file.pm" );
         $self->{file} = $file;
@@ -151,12 +140,7 @@ sub mk_component {
             $comp = 'Controller' if $type eq 'C';
             my $class = "Catalyst::Helper::$comp\::$helper";
             eval "require $class";
-
-            if ($@) {
-                Catalyst::Exception->throw(
-                    message => qq/Couldn't load helper "$class", "$@"/ );
-            }
-
+            die qq/Couldn't load helper "$class", "$@"/ if $@;
             if ( $class->can('mk_compclass') ) {
                 return 1 unless $class->mk_compclass( $self, @args );
             }
@@ -189,12 +173,11 @@ sub mk_dir {
         print qq/ exists "$dir"\n/;
         return 0;
     }
-    if ( mkpath [$dir] ) {
+    if ( mkpath $dir) {
         print qq/created "$dir"\n/;
         return 1;
     }
-
-    Catalyst::Exception->throw( message => qq/Couldn't create "$dir", "$!"/ );
+    die qq/Couldn't create "$dir", "$!"/;
 }
 
 =head3 mk_file
@@ -207,20 +190,14 @@ sub mk_file {
     my ( $self, $file, $content ) = @_;
     if ( -e $file ) {
         print qq/ exists "$file"\n/;
-        return 0 unless $self->{'.newfiles'};
-        if ( my $f = IO::File->new("< $file") ) {
-            my $oldcontent = join( '', (<$f>) );
-            return 0 if $content eq $oldcontent;
-        }
-        $file .= '.new';
+        return 0;
     }
     if ( my $f = IO::File->new("> $file") ) {
         print $f $content;
         print qq/created "$file"\n/;
         return 1;
     }
-
-    Catalyst::Exception->throw( message => qq/Couldn't create "$file", "$!"/ );
+    die qq/Couldn't create "$file", "$!"/;
 }
 
 =head3 next_test
@@ -233,16 +210,13 @@ sub next_test {
     else {
         my $name   = $self->{name};
         my $prefix = $name;
-        $prefix =~ s/::/-/g;
-        $prefix         = $prefix;
+        $prefix =~ s/::/_/g;
+        $prefix         = lc $prefix;
         $tname          = $prefix . '.t';
         $self->{prefix} = $prefix;
-        $prefix         = lc $prefix;
-        $prefix =~ s/-/\//g;
-        $self->{uri} = $prefix;
     }
     my $dir  = $self->{test_dir};
-    my $type = $self->{type};
+    my $type = lc $self->{type};
     return File::Spec->catfile( $dir, $type, $tname );
 }
 
@@ -260,9 +234,7 @@ sub render_file {
     my $template = $self->get_file( ( caller(0) )[0], $file );
     return 0 unless $template;
     my $output;
-    $t->process( \$template, { %{$self}, %$vars }, \$output )
-      || Catalyst::Exception->throw(
-        message => qq/Couldn't process "$file", / . $t->error() );
+    $t->process( \$template, { %{$self}, %$vars }, \$output );
     $self->mk_file( $path, $output );
 }
 
@@ -277,9 +249,9 @@ sub _mk_dirs {
     $self->mk_dir( $self->{root} );
     $self->{t} = File::Spec->catdir( $self->{dir}, 't' );
     $self->mk_dir( $self->{t} );
-    $self->mk_dir( File::Spec->catdir( $self->{t}, 'M' ) );
-    $self->mk_dir( File::Spec->catdir( $self->{t}, 'V' ) );
-    $self->mk_dir( File::Spec->catdir( $self->{t}, 'C' ) );
+    $self->mk_dir( File::Spec->catdir( $self->{t}, 'm' ) );
+    $self->mk_dir( File::Spec->catdir( $self->{t}, 'v' ) );
+    $self->mk_dir( File::Spec->catdir( $self->{t}, 'c' ) );
     $self->{class} = File::Spec->catdir( split( /\:\:/, $self->{name} ) );
     $self->{mod} = File::Spec->catdir( $self->{lib}, $self->{class} );
     $self->mk_dir( $self->{mod} );
@@ -298,12 +270,6 @@ sub _mk_appclass {
     $self->render_file( 'appclass', "$mod.pm" );
 }
 
-sub _mk_build {
-    my $self = shift;
-    my $dir  = $self->{dir};
-    $self->render_file( 'build', "$dir\/Build.PL" );
-}
-
 sub _mk_makefile {
     my $self = shift;
     my $dir  = $self->{dir};
@@ -332,43 +298,38 @@ sub _mk_apptest {
 }
 
 sub _mk_cgi {
-    my $self      = shift;
-    my $script    = $self->{script};
-    my $appprefix = $self->{appprefix};
-    $self->render_file( 'cgi', "$script\/$appprefix\_cgi.pl" );
-    chmod 0700, "$script/$appprefix\_cgi.pl";
+    my $self   = shift;
+    my $script = $self->{script};
+    $self->render_file( 'cgi', "$script\/cgi.pl" );
+    chmod 0700, "$script/cgi.pl";
 }
 
-sub _mk_fastcgi {
-    my $self      = shift;
-    my $script    = $self->{script};
-    my $appprefix = $self->{appprefix};
-    $self->render_file( 'fastcgi', "$script\/$appprefix\_fastcgi.pl" );
-    chmod 0700, "$script/$appprefix\_fastcgi.pl";
+sub _mk_fcgi {
+    my $self   = shift;
+    my $script = $self->{script};
+    $self->render_file( 'fcgi', "$script\/fcgi.pl" );
+    chmod 0700, "$script/fcgi.pl";
 }
 
 sub _mk_server {
-    my $self      = shift;
-    my $script    = $self->{script};
-    my $appprefix = $self->{appprefix};
-    $self->render_file( 'server', "$script\/$appprefix\_server.pl" );
-    chmod 0700, "$script/$appprefix\_server.pl";
+    my $self   = shift;
+    my $script = $self->{script};
+    $self->render_file( 'server', "$script\/server.pl" );
+    chmod 0700, "$script/server.pl";
 }
 
 sub _mk_test {
-    my $self      = shift;
-    my $script    = $self->{script};
-    my $appprefix = $self->{appprefix};
-    $self->render_file( 'test', "$script/$appprefix\_test.pl" );
-    chmod 0700, "$script/$appprefix\_test.pl";
+    my $self   = shift;
+    my $script = $self->{script};
+    $self->render_file( 'test', "$script/test.pl" );
+    chmod 0700, "$script/test.pl";
 }
 
 sub _mk_create {
-    my $self      = shift;
-    my $script    = $self->{script};
-    my $appprefix = $self->{appprefix};
-    $self->render_file( 'create', "$script\/$appprefix\_create.pl" );
-    chmod 0700, "$script/$appprefix\_create.pl";
+    my $self   = shift;
+    my $script = $self->{script};
+    $self->render_file( 'create', "$script\/create.pl" );
+    chmod 0700, "$script/create.pl";
 }
 
 sub _mk_compclass {
@@ -419,7 +380,7 @@ Sebastian Riedel, C<sri@oook.de>
 
 =head1 LICENSE
 
-This library is free software . You can redistribute it and/or modify
+This library is free software . You can redistribute it and/or modify 
 it under the same terms as perl itself.
 
 =cut
@@ -435,117 +396,68 @@ use Catalyst qw/-Debug/;
 
 our $VERSION = '0.01';
 
-[% name %]->config( name => '[% name %]' );
+[% name %]->config(
+    name => '[% name %]',
+    root => '[% base %]/root',
+);
 
 [% name %]->setup;
 
+sub default : Private {
+    my ( $self, $c ) = @_;
+    $c->res->output('Congratulations, [% name %] is on Catalyst!');
+}
+
 =head1 NAME
 
-[% name %] - Catalyst based application
+[% name %] - A very nice application
 
 =head1 SYNOPSIS
 
-    script/[% appprefix %]_server.pl
+    Very simple to use
 
 =head1 DESCRIPTION
 
-Catalyst based application.
-
-=head1 METHODS
-
-=over 4
-
-=item default
-
-=cut
-
-sub default : Private {
-    my ( $self, $c ) = @_;
-
-    # Hello World
-    $c->response->output('Congratulations, [% name %] is on Catalyst!');
-}
-
-#=item end
-#
-#=cut
-#
-#sub end : Private {
-#    my ( $self, $c ) = @_;
-#
-#    # Forward to View unless response body is already defined
-#    $c->forward('MyApp::V::') unless $c->response->body;
-#}
-
-=back
+Very nice application.
 
 =head1 AUTHOR
 
-[% author %]
+[%author%]
 
 =head1 LICENSE
 
-This library is free software . You can redistribute it and/or modify
+This library is free software . You can redistribute it and/or modify 
 it under the same terms as perl itself.
 
 =cut
 
 1;
+
 __makefile__
-    unless ( eval "use Module::Build::Compat 0.02; 1" ) {
-        print "This module requires Module::Build to install itself.\n";
+use ExtUtils::MakeMaker;
 
-        require ExtUtils::MakeMaker;
-        my $yn =
-          ExtUtils::MakeMaker::prompt( '  Install Module::Build now from CPAN?',            'y' );
-
-        unless ( $yn =~ /^y/i ) {
-            die " *** Cannot install without Module::Build.  Exiting ...\n";
-        }
-
-        require Cwd;
-        require File::Spec;
-        require CPAN;
-
-        # Save this 'cause CPAN will chdir all over the place.
-        my $cwd      = Cwd::cwd();
-        my $makefile = File::Spec->rel2abs($0);
-
-        CPAN::Shell->install('Module::Build::Compat')
-          or die " *** Cannot install without Module::Build.  Exiting ...\n";
-
-        chdir $cwd or die "Cannot chdir() back to $cwd: $!";
-    }
-    eval "use Module::Build::Compat 0.02; 1" or die $@;
-    use lib '_build/lib';
-    Module::Build::Compat->run_build_pl( args => \@ARGV );
-    require Module::Build;
-    Module::Build::Compat->write_makefile( build_class => 'Module::Build' );
-__build__
-use strict;
-use Catalyst::Build;
-
-my $build = Catalyst::Build->new(
-    create_makefile_pl => 'passthrough',
-    license            => 'perl',
-    module_name        => '[% name %]',
-    requires           => { Catalyst => '5.10' },
-    create_makefile_pl => 'passthrough',
-    script_files       => [ glob('script/*') ],
-    test_files         => [ glob('t/*.t'), glob('t/*/*.t') ]
+WriteMakefile(
+    NAME         => '[% name %]',
+    VERSION_FROM => 'lib/[% class %].pm',
+    PREREQ_PM    => { Catalyst => 5 },
+    test         => { TESTS => join ' ', ( glob('t/*.t'), glob('t/*/*.t') ) }
 );
-$build->create_build_script;
+
 __readme__
-Run script/[% appprefix %]_server.pl to test the application.
+Run script/server.pl to test the application.
+
 __changes__
-This file documents the revision history for Perl extension [% name %].
+This file documents the revision history for Perl extension $name.
+
 0.01  [% time %]
         - initial revision, generated by Catalyst
+
 __apptest__
 use Test::More tests => 2;
 use_ok( Catalyst::Test, '[% name %]' );
 
 ok( request('/')->is_success );
+
 __podtest__
 use Test::More;
 
@@ -554,6 +466,7 @@ plan skip_all => 'Test::Pod 1.14 required' if $@;
 plan skip_all => 'set TEST_POD to enable this test' unless $ENV{TEST_POD};
 
 all_pod_files_ok();
+
 __podcoveragetest__
 use Test::More;
 
@@ -562,10 +475,10 @@ plan skip_all => 'Test::Pod::Coverage 1.04 required' if $@;
 plan skip_all => 'set TEST_POD to enable this test' unless $ENV{TEST_POD};
 
 all_pod_coverage_ok();
+
 __cgi__
 [% startperl %] -w
-
-BEGIN { $ENV{CATALYST_ENGINE} ||= 'CGI' }
+BEGIN { $ENV{CATALYST_ENGINE} = 'CGI' }
 
 use strict;
 use FindBin;
@@ -578,7 +491,7 @@ use [% name %];
 
 =head1 NAME
 
-[% appprefix %]_cgi.pl - Catalyst CGI
+cgi - Catalyst CGI
 
 =head1 SYNOPSIS
 
@@ -596,14 +509,15 @@ Sebastian Riedel, C<sri@oook.de>
 
 Copyright 2004 Sebastian Riedel. All rights reserved.
 
-This library is free software. You can redistribute it and/or modify
+This library is free software. You can redistribute it and/or modify 
 it under the same terms as perl itself.
 
 =cut
-__fastcgi__
+
+__fcgi__
 [% startperl %] -w
 
-BEGIN { $ENV{CATALYST_ENGINE} ||= 'FastCGI' }
+BEGIN { $ENV{CATALYST_ENGINE} = 'FCGI' }
 
 use strict;
 use FindBin;
@@ -616,7 +530,7 @@ use [% name %];
 
 =head1 NAME
 
-[% appprefix %]_fastcgi.pl - Catalyst FastCGI
+fcgi - Catalyst FCGI
 
 =head1 SYNOPSIS
 
@@ -624,7 +538,7 @@ See L<Catalyst::Manual>
 
 =head1 DESCRIPTION
 
-Run a Catalyst application as fastcgi.
+Run a Catalyst application as fcgi.
 
 =head1 AUTHOR
 
@@ -634,15 +548,16 @@ Sebastian Riedel, C<sri@oook.de>
 
 Copyright 2004 Sebastian Riedel. All rights reserved.
 
-This library is free software. You can redistribute it and/or modify
+This library is free software. You can redistribute it and/or modify 
 it under the same terms as perl itself.
 
 =cut
+
 __server__
 [% startperl %] -w
 
 BEGIN { 
-    $ENV{CATALYST_ENGINE} ||= 'HTTP';
+    $ENV{CATALYST_ENGINE} = 'HTTP';
     $ENV{CATALYST_SCRIPT_GEN} = [% scriptgen %];
 }  
 
@@ -653,36 +568,27 @@ use FindBin;
 use lib "$FindBin::Bin/../lib";
 use [% name %];
 
-my $fork = 0;
 my $help = 0;
-my $host = undef;
 my $port = 3000;
 
-GetOptions(
-    'fork'   => \$fork,
-    'help|?' => \$help,
-    'host=s' => \$host,
-    'port=s' => \$port
-);
+GetOptions( 'help|?' => \$help, 'port=s' => \$port );
 
 pod2usage(1) if $help;
 
-[% name %]->run( $port, $host, $fork );
+[% name %]->run($port);
 
 1;
 
 =head1 NAME
 
-[% appprefix %]_server.pl - Catalyst Testserver
+server - Catalyst Testserver
 
 =head1 SYNOPSIS
 
-[% appprefix %]_server.pl [options]
+server.pl [options]
 
  Options:
-   -f -fork    handle each request in a new process
    -? -help    display this help and exits
-      -host    host (defaults to all)
    -p -port    port (defaults to 3000)
 
  See also:
@@ -701,14 +607,15 @@ Sebastian Riedel, C<sri@oook.de>
 
 Copyright 2004 Sebastian Riedel. All rights reserved.
 
-This library is free software. You can redistribute it and/or modify
+This library is free software. You can redistribute it and/or modify 
 it under the same terms as perl itself.
 
 =cut
+
 __test__
 [% startperl %] -w
 
-BEGIN { $ENV{CATALYST_ENGINE} ||= 'Test' }
+BEGIN { $ENV{CATALYST_ENGINE} = 'Test' }
 
 use strict;
 use Getopt::Long;
@@ -729,18 +636,18 @@ print [% name %]->run($ARGV[0])->content . "\n";
 
 =head1 NAME
 
-[% appprefix %]_test.pl - Catalyst Test
+test - Catalyst Test
 
 =head1 SYNOPSIS
 
-[% appprefix %]_test.pl [options] uri
+test.pl [options] uri
 
  Options:
    -help    display this help and exits
 
  Examples:
-   [% appprefix %]_test.pl http://localhost/some_action
-   [% appprefix %]_test.pl /some_action
+   test.pl http://localhost/some_action
+   test.pl /some_action
 
  See also:
    perldoc Catalyst::Manual
@@ -758,10 +665,11 @@ Sebastian Riedel, C<sri@oook.de>
 
 Copyright 2004 Sebastian Riedel. All rights reserved.
 
-This library is free software. You can redistribute it and/or modify
+This library is free software. You can redistribute it and/or modify 
 it under the same terms as perl itself.
 
 =cut
+
 __create__
 [% startperl %] -w
 
@@ -771,38 +679,36 @@ use Pod::Usage;
 use Catalyst::Helper;
 
 my $help = 0;
-my $nonew = 0;
 
-GetOptions( 'help|?' => \$help,
-	    'nonew'  => \$nonew );
+GetOptions( 'help|?' => \$help );
 
 pod2usage(1) if ( $help || !$ARGV[0] );
 
-my $helper = Catalyst::Helper->new({'.newfiles' => !$nonew});
+my $helper = Catalyst::Helper->new;
 pod2usage(1) unless $helper->mk_component( '[% name %]', @ARGV );
 
 1;
 
 =head1 NAME
 
-[% appprefix %]_create.pl - Create a new Catalyst Component
+create - Create a new Catalyst Component
 
 =head1 SYNOPSIS
 
-[% appprefix %]_create.pl [options] model|view|controller name [helper] [options]
+create.pl [options] model|view|controller name [helper] [options]
 
  Options:
    -help    display this help and exits
-   -nonew   don't create a .new file where a file to be created exists
 
  Examples:
-   [% appprefix %]_create.pl controller My::Controller
-   [% appprefix %]_create.pl view My::View
-   [% appprefix %]_create.pl view MyView TT
-   [% appprefix %]_create.pl view TT TT
-   [% appprefix %]_create.pl model My::Model
-   [% appprefix %]_create.pl model SomeDB CDBI dbi:SQLite:/tmp/my.db
-   [% appprefix %]_create.pl model AnotherDB CDBI dbi:Pg:dbname=foo root 4321
+   create.pl controller My::Controller
+   create.pl view My::View
+   create.pl view MyView TT
+   create.pl view TT TT
+   create.pl model My::Model
+   create.pl model SomeDB CDBI dbi:SQLite:/tmp/my.db
+   create.pl model AnotherDB CDBI dbi:Pg:dbname=foo root 4321
+   create.pl Ajax
 
  See also:
    perldoc Catalyst::Manual
@@ -812,10 +718,6 @@ pod2usage(1) unless $helper->mk_component( '[% name %]', @ARGV );
 
 Create a new Catalyst Component.
 
-Existing component files are not overwritten.  If any of the component files
-to be created already exist the file will be written with a '.new' suffix.
-This behaviour can be supressed with the C<-nonew> option.
-
 =head1 AUTHOR
 
 Sebastian Riedel, C<sri\@oook.de>
@@ -824,65 +726,56 @@ Sebastian Riedel, C<sri\@oook.de>
 
 Copyright 2004 Sebastian Riedel. All rights reserved.
 
-This library is free software. You can redistribute it and/or modify
+This library is free software. You can redistribute it and/or modify 
 it under the same terms as perl itself.
 
 =cut
+
 __compclass__
 package [% class %];
 
 use strict;
 use base 'Catalyst::Base';
 
+[% IF type == 'C' %]
+sub default : Private {
+    my ( $self, $c ) = @_;
+    $c->res->output('Congratulations, [% class %] is on Catalyst!');
+}
+
+[% END %]
 =head1 NAME
 
-[% class %] - Catalyst component
+[% class %] - A Component
 
 =head1 SYNOPSIS
 
-See L<[% app %]>
+    Very simple to use
 
 =head1 DESCRIPTION
 
-Catalyst component.
-[% IF type == 'C' %]
-=head1 METHODS
+Very nice component.
 
-=over 4
-
-=item default
-
-=cut
-
-sub default : Private {
-    my ( $self, $c ) = @_;
-
-    # Hello World
-    $c->response->output('Congratulations, [% class %] is on Catalyst!');
-}
-
-=back
-
-[% END %]
 =head1 AUTHOR
 
 [%author%]
 
 =head1 LICENSE
 
-This library is free software . You can redistribute it and/or modify
+This library is free software . You can redistribute it and/or modify 
 it under the same terms as perl itself.
 
 =cut
 
 1;
+
 __comptest__
 [% IF type == 'C' %]
 use Test::More tests => 3;
 use_ok( Catalyst::Test, '[% app %]' );
 use_ok('[% class %]');
 
-ok( request('[% uri %]')->is_success );
+ok( request('[% prefix %]')->is_success );
 [% ELSE %]
 use Test::More tests => 1;
 use_ok('[% class %]');
