@@ -3,13 +3,11 @@ package Catalyst::Request::Upload;
 use strict;
 use base 'Class::Accessor::Fast';
 
-use Catalyst::Exception;
 use File::Copy ();
 use IO::File   ();
 
-__PACKAGE__->mk_accessors(qw/filename headers size tempname type/);
+__PACKAGE__->mk_accessors(qw/filename size tempname type/);
 
-sub new { shift->SUPER::new( ref( $_[0] ) ? $_[0] : {@_} ) }
 
 =head1 NAME
 
@@ -20,10 +18,8 @@ Catalyst::Request::Upload - Catalyst Request Upload Class
     $upload->copy_to
     $upload->fh
     $upload->filename;
-    $upload->headers;
     $upload->link_to;
     $upload->size;
-    $upload->slurp;
     $upload->tempname;
     $upload->type;
 
@@ -40,7 +36,11 @@ to the upload data.
 
 =item $upload->new
 
-simple constructor.
+Constructor. Normally only for engine use.
+
+=cut 
+
+sub new { shift->SUPER::new( ref( $_[0] ) ? $_[0] : {@_} ) }
 
 =item $upload->copy_to
 
@@ -64,15 +64,8 @@ Opens tempname and returns a C<IO::File> handle.
 sub fh {
     my $self = shift;
 
-    my $fh = IO::File->new( $self->tempname, IO::File::O_RDONLY );
-
-    unless ( defined $fh ) {
-
-        my $filename = $self->tempname;
-
-        Catalyst::Exception->throw(
-            message => qq/Can't open '$filename': '$!'/ );
-    }
+    my $fh = IO::File->new( $self->tempname, IO::File::O_RDONLY )
+      or die( "Can't open ", $self->tempname, ": ", $! );
 
     return $fh;
 }
@@ -81,10 +74,6 @@ sub fh {
 
 Contains client supplied filename.
 
-=item $upload->headers
-
-Returns a C<HTTP::Headers> object.
-
 =item $upload->link_to
 
 Creates a hard link to the tempname.  Returns true for success, 
@@ -103,31 +92,6 @@ sub link_to {
 
 Contains size of the file in bytes.
 
-=item $upload->slurp
-
-Returns a scalar containing contents of tempname.
-
-=cut
-
-sub slurp {
-    my ( $self, $layer ) = @_;
-
-    unless ($layer) {
-        $layer = ':raw';
-    }
-
-    my $content = undef;
-    my $handle  = $self->fh;
-
-    binmode( $handle, $layer );
-
-    while ( $handle->sysread( my $buffer, 8192 ) ) {
-        $content .= $buffer;
-    }
-
-    return $content;
-}
-
 =item $upload->tempname
 
 Contains path to the temporary spool file.
