@@ -1,9 +1,6 @@
 package Catalyst::Test;
 
 use strict;
-
-use Catalyst::Exception;
-use Catalyst::Utils;
 use UNIVERSAL::require;
 
 $ENV{CATALYST_ENGINE} = 'Test';
@@ -23,19 +20,19 @@ Catalyst::Test - Test Catalyst applications
     get('index.html');
 
     # Run tests against a remote server
-    CATALYST_SERVER='http://localhost:3000/' prove -r -l lib/ t/
+    CATALYST_SERVER='http://localhost:3000/' prove -l lib/ t/
 
     # Tests with inline apps need to use Catalyst::Engine::Test
     package TestApp;
 
     use Catalyst qw[-Engine=Test];
 
-    sub foo : Global {
+    __PACKAGE__->action(
+        foo => sub {
             my ( $self, $c ) = @_;
             $c->res->output('bar');
-    }
-
-    __PACKAGE__->setup();
+        }
+    );
 
     package main;
 
@@ -79,7 +76,9 @@ sub import {
 
     else {
         $class->require;
-		die if $@ && $@ !~ /^Can't locate /;
+        my $error = $UNIVERSAL::require::ERROR;
+        die qq/Couldn't load "$class", "$error"/ if $@;
+
         $class->import;
 
         $request = sub { $class->run(@_) };
@@ -96,15 +95,28 @@ my $agent;
 
 =item remote_request
 
-Do an actual remote request using LWP.
+Do an actual remote rquest using LWP.
 
 =cut
 
 sub remote_request {
+    my $request = shift;
 
     require LWP::UserAgent;
 
-    my $request = Catalyst::Utils::request( shift(@_) );
+    unless ( ref $request ) {
+
+        my $uri =
+          ( $request =~ m/http/i )
+          ? URI->new($request)
+          : URI->new( 'http://localhost' . $request );
+
+        $request = $uri->canonical;
+    }
+
+    unless ( ref $request eq 'HTTP::Request' ) {
+        $request = HTTP::Request->new( 'GET', $request );
+    }
 
     my $server = URI->new( $ENV{CATALYST_SERVER} );
 
@@ -118,13 +130,13 @@ sub remote_request {
     $request->uri->path( $server->path . $request->uri->path );
 
     unless ($agent) {
-
         $agent = LWP::UserAgent->new(
+
+            #  cookie_jar   => {},
             keep_alive   => 1,
             max_redirect => 0,
             timeout      => 60,
         );
-
         $agent->env_proxy;
     }
 
